---

slug: /obshell-overview
---

# Overview

OceanBase Shell (obshell) is a local database command-line tool provided by OceanBase for administrators and developers. It is a no-installation, out-of-the-box tool. obshell supports cluster and standalone (seekdb) operations, enabling unified management of different ecosystem products for the same database. This simplifies integration with third-party tools and reduces the complexity and cost of managing seekdb and OceanBase Database.

obshell does not require additional installation. By default, after you install OceanBase seekdb through any method, you can find the obshell executable file in the `usr/bin` directory of the installation directory. 